# Citations

This file includes citations and attributions required to use example datasets.

## [MovieLens](https://grouplens.org/datasets/movielens/latest/)

- F. Maxwell Harper and Joseph A. Konstan. 2015. The MovieLens Datasets: History and Context. ACM Transactions on Interactive Intelligent Systems (TiiS) 5, 4: 19:1–19:19. https://doi.org/10.1145/2827872

## [IMDB](https://datasets.imdbws.com/)

- Information courtesy of IMDb (https://www.imdb.com). Used with permission.

## [Palmer Penguins](https://allisonhorst.github.io/palmerpenguins/)

- Horst AM, Hill AP, Gorman KB (2020). palmerpenguins: Palmer Archipelago (Antarctica) penguin data. R package version 0.1.0. https://allisonhorst.github.io/palmerpenguins/. doi: 10.5281/zenodo.3960218.
